@@ -72,7 +72,7 @@ class SantaMonicaScraper(EngageScraper):
     def base_agenda_location(self, base_location):
         self._base_agenda_location = base_location
 
-    def set_committee(self, commmittee_name):
+    def set_committee(self, committee_name):
         committee = self._DBsession().query(Committee).filter(
             Committee.name == committee_name).first()
         if committee is not None:
@@ -459,7 +459,7 @@ class SantaMonicaScraper(EngageScraper):
                         'committee_id': self._Committee.id,
                     }
 
-                    es_load = self._elasticsearch_utility.postItems(es_item)
+                    es_load = self._elasticsearch_utility.postItem(es_item)
                     if SCRAPER_DEBUG:
                         log.info(es_load)
 
